<?php

namespace Drupal\civic_ai\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Defines the settings form for the Civic AI Navigator module.
 */
class SettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['civic_ai.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'civic_ai_settings_form';
  }

  /**
   * Builds the settings form.
   *
   * @param array $form
   *   An associative array containing the structure of the form.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The current state of the form.
   *
   * @return array
   *   The form structure.
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('civic_ai.settings');

    $form['status'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enable Civic AI Navigator'),
      '#default_value' => $config->get('status') ?? FALSE,
    ];

    $form['civic_id'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Civic ID'),
      '#default_value' => $config->get('civic_id') ?? '',
      '#required' => TRUE,
    ];

    $form['js_position'] = [
      '#type' => 'radios',
      '#title' => $this->t('JS Position'),
      '#options' => ['header' => 'Header', 'footer' => 'Footer'],
      '#default_value' => $config->get('js_position') ?? 'header',
    ];

    $form['pages'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Pages'),
      '#description' => $this->t('One path per line. Use * for wildcards. Leave empty for all pages.'),
      '#default_value' => $config->get('pages') ?? '',
    ];

    return parent::buildForm($form, $form_state);
  }

  public function submitForm(array &$form, FormStateInterface $form_state) {
    $pages = array_map('trim', explode("\n", strtolower($form_state->getValue('pages'))));
    $pages = implode("\n", array_filter($pages));

    $this->config('civic_ai.settings')
      ->set('status', $form_state->getValue('status'))
      ->set('civic_id', $form_state->getValue('civic_id'))
      ->set('js_position', $form_state->getValue('js_position'))
      ->set('pages', $pages)
      ->save();

    parent::submitForm($form, $form_state);
  }
}
